aboutsummaryrefslogtreecommitdiff
path: root/Perl/Makefile.PL
diff options
context:
space:
mode:
authorlecoanet2000-02-02 13:59:32 +0000
committerlecoanet2000-02-02 13:59:32 +0000
commit2b91521b4c124546e59638f2e990dcbc75903d85 (patch)
treebaa98640217261a2b1ffce90e9dede2386fa87dd /Perl/Makefile.PL
parent718ca6879f5614bf9a023c538fb094750d546122 (diff)
downloadtkzinc-2b91521b4c124546e59638f2e990dcbc75903d85.zip
tkzinc-2b91521b4c124546e59638f2e990dcbc75903d85.tar.gz
tkzinc-2b91521b4c124546e59638f2e990dcbc75903d85.tar.bz2
tkzinc-2b91521b4c124546e59638f2e990dcbc75903d85.tar.xz
Passage en Zinc.
Adaptation � Solaris et d�termination auto des chemins dans Makefile.
Diffstat (limited to 'Perl/Makefile.PL')
-rw-r--r--Perl/Makefile.PL20
1 files changed, 12 insertions, 8 deletions
diff --git a/Perl/Makefile.PL b/Perl/Makefile.PL
index a366b55..6e1467f 100644
--- a/Perl/Makefile.PL
+++ b/Perl/Makefile.PL
@@ -1,17 +1,21 @@
#
# The first argument should be the name of the radar library
# either ptkradar or ptkradr_debug for example.
#
use Tk::MMutil;
use Tk::Config;
Tk::MMutil::TkExtMakefile(
- 'NAME' => 'Tk::Radar',
- 'OBJECT' => '$(O_FILES)',
- 'VERSION_FROM' => 'Radar.pm',
- 'XS_VERSION' => $Tk::Config::VERSION,
- 'INC' => "-I. -I/usr/lib/perl5/i386-linux/5.004/Tk/pTk",
- 'LIBS' => "-L/usr/X11R6/lib -L.. -l$ARGV[0] -lX11");
+ 'CC' => 'gcc',
+ 'LD' => 'gcc',
+ 'CCCDLFLAGS' => '-fPIC',
+ 'NAME' => 'Tk::Zinc',
+ 'OBJECT' => '$(O_FILES)',
+ 'VERSION_FROM' => 'Zinc.pm',
+ 'XS_VERSION' => $Tk::Config::VERSION,
+ 'INC' => "-I. -I$ARGV[1]",
+ 'LIBS' => "-L/usr/X11R6/lib -L.. -l$ARGV[0] -lX11");
@@ -1,17 +1,21 @@
#
-# The first argument should be the name of the radar library
-# either ptkradar or ptkradr_debug for example.
+# The first argument should be the name of the zinc library
+# either ptkzinc or ptkzinc_debug for example. The second
+# argument is the path to pTk in the system.
#
use Tk::MMutil;